<?php

/**
 * @table integration
 * @id invision4
 * @title Invision Power Board
 * @visible_link http://www.invisionpower.com/ip.dynamic/products/board/index.html
 * @description Invision Power Board, an award-winning scaleable bulletin board
 * system, allows you to effortlessly build, manage and promote your online
 * community. Advanced yet intuitive features like multi-moderation allow you
 * to focus on developing your community, rather than wrestling with
 * complex settings.
 * @different_groups 1
 * @single_login 1
 * @type Bulletin Boards
 * @am_protect_api 6.0
 */
class Am_Protect_Invision4 extends Am_Protect_Databased
{
    const PLUGIN_STATUS = self::STATUS_BETA; //dev status
    const PLUGIN_COMM = self::COMM_COMMERCIAL; //paid
    const PLUGIN_REVISION = '6.3.19';

    protected $groupMode = self::GROUP_MULTI;
    protected $guessTablePattern = "core_members";
    protected $guessFieldsPattern = [
        'email',
        'members_pass_hash',
        'members_pass_salt',
        'joined',
        'member_group_id',
        'mgroup_others'
    ];
    const INVISION4 = 'Invision4';
    const INVISION = 'Invision';
    const USER_TYPE_NORMAL = 0;
    const USER_TYPE_INACTIVE = 1;
    protected $_ipbconfig = [];

    function canAutoCreate()
    {
        return true;
    }

    public function afterAddConfigItems($form)
    {
        $form->addHidden("protect.{$this->getId()}.banned_group");
        $form->addHidden("protect.{$this->getId()}.member_group");
        $form->addHidden("protect.{$this->getId()}.admin_group");
        $form->addHidden("protect.{$this->getId()}.guest_group");
        $form->addText("protect.{$this->getId()}.cookie_prefix")->setLabel('Cookie Prefix');
        $form->addSelect("protect.{$this->getId()}.display_name", '', [
            'options' => [
                    'username' => 'Username',
                    'name_f_name_l' => 'First & Last Name'
            ]
        ])
            ->setLabel('Set display name for new users to');

        $form->addSelect("protect.{$this->getId()}.version", '', ['options'=> ['4'=>' less then 4.2', '4.2' =>'4.2', '4.3' =>'4.3 or more']])->setLabel('IPB version');
        if($this->getDi()->plugins_misc->isEnabled('avatar'))
            $form->addAdvCheckbox("protect.{$this->getId()}.use_avatar")->setLabel(___("Add user's avatar from aMember to IPB"));
    }

    public function getIntegrationFormElements(HTML_QuickForm2_Container $group)
    {
        parent::getIntegrationFormElements($group);
        $options = [];
        foreach($this->getAvailableUserGroups() as $gr){
            $options[$gr->getId()] = $gr->getTitle();
        }

        $group->addMagicSelect('additional_groups', [], ['options'=>$options])->setLabel('Additional Groups');
    }

    public function getIntegrationSettingDescription(array $config)
    {
        $ret = [];
        $g = [$config['gr']];

        if (isset($config['additional_groups']) && $config['additional_groups']) {
            $g = array_merge($g, $config['additional_groups']);
        }
        foreach($this->getAvailableUserGroups() as $gr){
            if (in_array($gr->getId(), $g)) {
                $ret[] = "[{$gr->getTitle()}]";
            }
        }

        return ___('Assign Group') . ' ' . implode(", ",  $ret);
    }

    public function getPasswordFormat()
    {
        switch ($this->getConfig('version')) {
            case '4.3':
                return SavedPassTable::PASSWORD_PASSWORD_HASH;
            default:
                return self::INVISION4;
        }
    }

    public function getPasswordFormat3()
    {
        return self::INVISION;
    }

    public function cryptPassword($pass, &$salt = null, User $user = null)
    {
        if(!$salt)
            $salt = $this->getDi()->security->randomString(22, 'QWERTYUASDFGHJKLZXCVBNM1234567890qwertyuioplkjhgfdsazxcvbnm');
        return crypt( $pass, '$2a$13$' . $salt );
    }

    function generateSalt3($len = 5)
    {
        srand((double)microtime() * 1000);
		$s = '';
		for($i=0;$i<$len;$i++)
		{
			$num   = rand(33, 126);
			if( $num == '92')
				$num = 93;
			$s .= chr($num);
		}
		return $s;
    }

    function parseCleanValue3($val, $postParse = true)
    {
        if ($val == "")
        {
            return "";
        }
        $val = str_replace("&#032;", " ", stripslashes($val));

        # Convert all carriage return combos
        $val = str_replace(["\r\n", "\n\r", "\r"], "\n", $val);

        $val = str_replace("&", "&amp;", $val);
        $val = str_replace("<!--", "&#60;&#33;--", $val);
        $val = str_replace("-->", "--&#62;", $val);
        $val = str_ireplace("<script", "&#60;script", $val);
        $val = str_replace(">", "&gt;", $val);
        $val = str_replace("<", "&lt;", $val);
        $val = str_replace('"', "&quot;", $val);
        $val = str_replace("\n", "<br />", $val); // Convert literal newlines
        $val = str_replace("$", "&#036;", $val);
        $val = str_replace("!", "&#33;", $val);
        $val = str_replace("'", "&#39;", $val); // IMPORTANT: It helps to increase sql query safety.
        //if ( IPS_ALLOW_UNICODE )
        {
            $val = preg_replace("/&amp;#([0-9]+);/s", "&#\\1;", $val);

            //-----------------------------------------
            // Try and fix up HTML entities with missing ;
            //-----------------------------------------

            $val = preg_replace('/&#(\d+?)([^\d;])/i', "&#\\1;\\2", $val);
        }

        return $val;
    }

    public function cryptPassword3($pass, &$salt = null, User $user = null)
    {
        $pass = $this->parseCleanValue3($pass);
        if(empty($salt)) $salt = $this->generateSalt3();
        $p = md5(md5($salt).md5($pass));
        return $p;
    }

    public function findPassword3(User $user, $returnNoPass = false)
    {
        // try find password
        $saved = $this->getDi()->savedPassTable->findSaved($user, $this->getPasswordFormat3());
        if ($saved)
            return $saved;
        /// else encrypt it again
        $pass = $user->getPlaintextPass();
        if ($pass)
        {
            $saved = $this->getDi()->savedPassRecord;
            $saved->user_id = $user->user_id;
            $saved->format = $this->getPasswordFormat3();
            $saved->salt = null;
            $saved->pass = $this->cryptPassword3($pass, $saved->salt, $user);
            $saved->insert();
            return $saved;
        }
        // nothing
        if ($returnNoPass)
        {
            $pass = $this->getDi()->savedPassRecord;
            $pass->pass = '-nopass-' . uniqid();
            $pass->salt = 'NNN';
            if ($user->isLoaded())
                $user->data()->set(self::USER_NEED_SETPASS, 1)->update();
            return $pass;
        }
    }

    public function parseExternalConfig($path)
    {
        $config_path = $path . "/conf_global.php";
        if (!is_file($config_path) || !is_readable($config_path))
            throw new Am_Exception_InputError("Specified path is not a valid Invision installation!");
        include($config_path);
        if (!$INFO['sql_host'] || !$INFO['sql_database'])
            throw new Am_Exception_InputError("Specified path is not a valid Invision installation!");
        $settings = [
            'host' => $INFO['sql_host'],
            'db' => $INFO['sql_database'],
            'user' => $INFO['sql_user'],
            'pass' => $INFO['sql_pass'],
            'prefix' => $INFO['sql_tbl_prefix'],
            'banned_group' => $INFO['banned_group'],
            'admin_group' => $INFO['admin_group'],
            'guest_group' => $INFO['guest_group'],
            'member_group' => $INFO['member_group'],
            'cookie_prefix' => 'ips4_'
        ];
        return $settings;
    }

    function getAvailableUserGroupsSql()
    {
        return "SELECT
                g.g_id as id,
                l.word_default as title,
                (g_id in (4)) as is_admin,
                (g_id in (5)) as is_banned
                FROM ?_core_groups g, ?_core_sys_lang_words l
                WHERE l.word_key = concat('core_group_',g.g_id)";
    }

    function Set_IPB_Cookie($name, $value="")
    {
		Am_Cookie::set($this->getConfig('cookie_prefix').$name, $value, time() + ( 7 * 86400 ), '/', $this->getDi()->request->getHttpHost());
    }

    function my_getenv($key)
    {
	    $return = [];
	    if(is_array($_SERVER) && count($_SERVER))
		    if(isset($_SERVER[$key]))
			    $return = $_SERVER[$key];
	    if(!$return)
		    $return = getenv($key);
	    return $return;
    }

	function Get_IPB_Cookie( $name )
	{
    	if(isset($_COOKIE[$this->getConfig('cookie_prefix').$name]))
   			return urldecode($_COOKIE[$this->getConfig('cookie_prefix').$name]);
   		return false;
	}

    public function generate_auto_log_in_key($len=60)
    {
        $pass = $this->generateSalt($len);
		return md5($pass);
    }

    public function loginUser(Am_Record $record, $password)
    {
        if ($this->getConfig('version', 4)>4)
            return $this->loginUser4_2($record, $password);

        $_time = time() + 7 * 86400;

		if(!$record->member_login_key || (time()>$record->member_login_key_expire))
		{
			$record->member_login_key = $this->generate_auto_log_in_key();
			$this->getDb()->query("UPDATE ?_core_members
							SET
							member_login_key_expire	= ?,
							member_login_key		= ?
							WHERE member_id				= ?
						",$_time,$record->member_login_key,$record->member_id);
		}
		$this->Set_IPB_Cookie( "member_id", $record->member_id);
		$this->Set_IPB_Cookie( "pass_hash", $record->member_login_key);
    }

    function loginUser4_2(Am_Record $record, $password)
    {
        $_time = time() + 7 * 86400;

        $device_key = $this->Get_IPB_Cookie('device_key');
        if(!$device_key){

            [$device_key, $login_key] = $this->getDb()->selectRow(
                 "SELECT device_key, login_key "
                 . "FROM ?_core_members_known_devices "
                 . "WHERE member_id=? AND user_agent=?",
                 $record->pk(), $this->my_getenv('HTTP_USER_AGENT')
                 );
        }
        if (!$device_key) {

            do {
                $device_key = $this->generate_auto_log_in_key();
            } while ($this->getDb()->selectCell("SELECT * FROM ?_core_members_known_devices WHERE device_key=? AND member_id=? LIMIT 1", $device_key, $record->pk()));

            $login_key = $this->generate_auto_log_in_key();
            $this->getDb()->query(
                "INSERT INTO ?_core_members_known_devices "
                . " SET device_key=?, member_id =?, user_agent=?, login_key=?, last_seen=?, login_handler=?",
                $device_key, $record->member_id, $this->my_getenv('HTTP_USER_AGENT'), $login_key, time(), 'Internal'
                );
        } else {
            $login_key = $this->generate_auto_log_in_key();
            $this->getDb()->query("update ?_core_members_known_devices set login_key = ? , last_seen = ? where device_key = ?", $login_key, time(), $device_key);
        }
        if ($device_key_ = $this->getDb()->selectCell(
                 "SELECT device_key "
                 . "FROM ?_core_members_known_ip_addresses "
                 . "WHERE member_id=? AND ip_address=?",
                 $record->pk(), $_SERVER['REMOTE_ADDR']
                 ))
        {
            $this->getDb()->query("update ?_core_members_known_ip_addresses set last_seen = ? where device_key = ? and ip_address = ? ", time(), $device_key, $_SERVER['REMOTE_ADDR']);
        }
        else
        {
            $this->getDb()->query(
                "INSERT INTO ?_core_members_known_ip_addresses "
                . " SET device_key=?, member_id =?, ip_address=?, last_seen=?",
                $device_key, $record->member_id, $_SERVER['REMOTE_ADDR'], time()
                );
        }
        if ($id = $this->Get_IPB_Cookie('IPSSessionFront')) {
            //force reload auth session from cookie
            $this->getDb()->query("DELETE FROM ?_core_sessions WHERE id=?", $id);
        }

		$this->Set_IPB_Cookie("member_id", $record->member_id);
		$this->Set_IPB_Cookie("login_key", $login_key);
		$this->Set_IPB_Cookie("device_key", $device_key);
    }

    public function getLoggedInRecord()
    {
        if ($id = $this->Get_IPB_Cookie('IPSSessionFront')) {
            if ($member_id = $this->getDb()->selectCell("SELECT member_id FROM ?_core_sessions WHERE id=?", $id)) {
                return $this->getTable()->load($member_id, false);
            }
        }

        $member_id = $this->Get_IPB_Cookie('member_id');
        if(!$member_id)
            return;

        $device_key = $this->Get_IPB_Cookie( "device_key");
        if(!$device_key)
            return;

        $login_key = $this->Get_IPB_Cookie('login_key');
        if(!$login_key)
            return;

        if(!($member = $this->getTable()->load($member_id, false)))
            return;

        // There should be a record in know_devices;
        if(!$this->getDb()->selectCell(
            "SELECT count(*) "
            . "FROM ?_core_members_known_devices "
            . "WHERE member_id=? AND device_key=? AND login_key=?",
            $member_id, $device_key, $login_key))
            return;

        return $member;
    }

    public function logoutUser(User $user)
    {
        if ($id = $this->Get_IPB_Cookie('IPSSessionFront')) {
            $this->getDb()->query("DELETE FROM ?_core_sessions WHERE id=?", $id);
        }

		$uid = $this->Get_IPB_Cookie( "member_id" );
		if(!$uid)
            return;

		$r = $this->getDb()->selectRow("SELECT * from ?_core_members where member_id=?",$uid );
		if( $r[ 'name' ] == '' )
		{
			return;
		}

		$this->Set_IPB_Cookie("member_id" , null);

        if($this->getConfig('version', 4) < 4.2) {
            $this->Set_IPB_Cookie( "pass_hash" , "0"  );
        } else {
            $this->Set_IPB_Cookie("login_key", null);
            $this->Set_IPB_Cookie("device_key", null);
        }

		$now = time();
        if($this->getConfig('version', 4) < 4.2)
    		$cookie_id = $this->Get_IPB_Cookie( 'session_id' );
        else
            $cookie_id = $this->Get_IPB_Cookie ('IPSSessionFront');


		$this->getDb()->query("UPDATE ?_core_members
						SET
						last_visit				= ?,
						last_activity			= ?
						WHERE member_id				= ?
					",$now,$now,$r['member_id']);
        $this->Set_IPB_Cookie("IPSSessionFront", null);
    }

    function getUserNameClean($user, $table)
    {
        switch ($this->getConfig('display_name', 'username'))
        {
            case 'name_f_name_l' :
                return ucwords($user->name_f . ' ' . $user->name_l);
            case 'username' :
            default:
                return $user->login;
        }
    }

    function getAvatar($user, $table)
    {
        return !empty($user->avatar) ?
            $this->getDi()->surl("misc/avatar/{$user->avatar}", false) :
            '';
    }

    function generateSalt($len = 5)
    {
        $return = '';
        if ( function_exists( 'random_bytes' ) )
        {
            $return = substr( bin2hex( random_bytes( $len ) ), 0, $len );
        }
        elseif( function_exists( 'openssl_random_pseudo_bytes' ) )
        {
            $return = substr( bin2hex( openssl_random_pseudo_bytes( ceil( $len / 2 ) ) ), 0, $len );
        }
        /* Fallback JUST IN CASE */
        if( !$return OR strlen( $return ) != $len )
        {
            $return = substr( md5( uniqid( '', true ) ) . md5( uniqid( '', true ) ), 0, $len );
        }
        return $return;
    }

    function parseCleanValue($val, $postParse = true)
    {
        if ($val == "")
        {
            return "";
        }
        $val = str_replace("&#032;", " ", stripslashes($val));

        # Convert all carriage return combos
        $val = str_replace(["\r\n", "\n\r", "\r"], "\n", $val);

        $val = str_replace("&", "&amp;", $val);
        $val = str_replace("<!--", "&#60;&#33;--", $val);
        $val = str_replace("-->", "--&#62;", $val);
        $val = str_ireplace("<script", "&#60;script", $val);
        $val = str_replace(">", "&gt;", $val);
        $val = str_replace("<", "&lt;", $val);
        $val = str_replace('"', "&quot;", $val);
        $val = str_replace("\n", "<br />", $val); // Convert literal newlines
        $val = str_replace("$", "&#036;", $val);
        $val = str_replace("!", "&#33;", $val);
        $val = str_replace("'", "&#39;", $val); // IMPORTANT: It helps to increase sql query safety.
        //if ( IPS_ALLOW_UNICODE )
        {
            $val = preg_replace("/&amp;#([0-9]+);/s", "&#\\1;", $val);

            //-----------------------------------------
            // Try and fix up HTML entities with missing ;
            //-----------------------------------------

            $val = preg_replace('/&#(\d+?)([^\d;])/i', "&#\\1;\\2", $val);
        }

        return $val;
    }

    function loginKey($len=60)
    {
        $pass = $this->generateSalt($len);
		return md5($pass);
    }

    function createTable()
    {
        $table = new Am_Protect_Invision4_Table($this, $this->getDb(), '?_core_members', 'member_id');
        $tableConfig = [
            [[$this, "getUserNameClean"], 'name'],
            [Am_Protect_Table::FIELD_EMAIL, 'email'],
            [Am_Protect_Table::FIELD_ADDED_STAMP, 'joined'],
            [Am_Protect_Table::FIELD_REMOTE_ADDR, 'ip_address'],
            [[$this, "getUserNameClean"], 'members_seo_name'],
            [Am_Protect_Table::FIELD_PASS, 'members_pass_hash'],
            [Am_Protect_Table::FIELD_SALT, 'members_pass_salt'],
            [':1', 'allow_admin_mails']
            //array(array($this, 'loginKey'), 'member_login_key'),
        ];
        if($this->getConfig('use_avatar'))
        {
            $tableConfig[] = [[$this, "getAvatar"], 'pp_main_photo'];
            $tableConfig[] = [[$this, "getAvatar"], 'pp_thumb_photo'];
            $tableConfig[] = [':custom', 'pp_photo_type'];
        }

        $table->setFieldsMapping($tableConfig);
        return $table;
    }

    function chooseGroups($groups, User $user = null)
    {
        if($user && $user->isLocked() && ($locked = $this->getLockedGroup()))
            return [$locked];
        $ret = [];
        $primary = [];
        $additional = [];
        foreach ($groups as $config){
            $primary[] = $config['gr'];
            if(is_array($config['additional_groups'])){
                $additional = array_merge($additional, $config['additional_groups']);
            }
        }
        rsort($primary);
        $groups = array_unique(array_filter(array_merge($primary, $additional)));
        $groups = $this->addSuperGroups($groups, $user);

        if ($this->_priority === null) $this->_initPriority();
        usort($groups, [$this, '_compareGroups']);
        return $groups;
    }

    function onCheckUniqLogin(Am_Event_CheckUniqLogin $event)
    {
        $table = $this->getTable();
        if ($table->findFirstByLogin($event->getLogin()))
            $event->setFailureAndStop();
    }
}

class Am_Protect_Invision4_Table extends Am_Protect_Table
{
    function createAmember(User $user, Am_Record $record)
    {
        parent::createAmember($user, $record);
        $user->login = $record->name;
    }

    /*function insertFromAmember(User $user, SavedPass $pass, $groups)
    {
        $record = parent::insertFromAmember($user, $pass, $groups);
        $stats = $this->getPlugin()->getDb()->selectCell("SELECT cs_value from ?_cache_store WHERE cs_key='stats'");
        $stats = unserialize($stats);
        $stats['mem_count'] = $this->getPlugin()->getDb()->selectCell("SELECT COUNT(*) FROM ?_members");
        $stats['last_mem_name'] = $record->name;
        $stats['last_mem_id'] = $record->member_id;
        $stats = serialize($stats);
        $this->getPlugin()->getDb()->query("UPDATE ?_cache_store SET cs_value=? WHERE cs_key='stats'", $stats);
        return $record;
    }*/

    function updateFromAmember(Am_Record $record, User $user, $groups)
    {
        parent::updateFromAmember($record, $user, $groups);
        $record->name = $record->members_seo_name = $record->members_l_username
            = $this->getPlugin()->getUserNameClean($user, $this);
        $record->updateSelectedFields(['name', 'members_seo_name']);
    }

    public function getGroups(Am_Record $record)
    {
        $groups = [$record->member_group_id];
        $groups = array_merge($groups, explode(',', $record->mgroup_others));
        return array_filter($groups);
    }

    public function setGroups(Am_Record $record, $groups) {
        $groups = array_filter($groups);
        $record->member_group_id = array_shift($groups);
        if (!$record->member_group_id)
            $record->member_banned = Am_Protect_Invision4::USER_TYPE_INACTIVE;
        else
            $record->member_banned = Am_Protect_Invision4::USER_TYPE_NORMAL;
        $record->mgroup_others = implode(',', $groups);
        $record->updateSelectedFields(['member_group_id', 'mgroup_others']);
    }

    public function checkPassword(Am_Record $record, User $user, $plaintextPass = null)
    {
        if ($plaintextPass)
        {
            if (password_verify($plaintextPass, $record->get($this->_passField)))
                return true;
        }
        if(!parent::checkPassword($record, $user, $plaintextPass))
            return $this->checkPassword3 ($record, $user, $plaintextPass);
        else
            return true;
    }

    function checkPassword3(Am_Record $record, User $user, $plaintextPass = null)
    {
        if ($plaintextPass)
        {
            $salt = $this->_saltField ? $record->get($this->_saltField) : $record->get($this->_passField);
            return $this->_plugin->cryptPassword3($plaintextPass, $salt, $user) === $record->get($this->_passField);
        } else {
            $saved = $this->_plugin->findPassword3($user);
            if (!$saved) return false;
            if ($record->get($this->_passField) != $saved->pass) return false;
            if ($this->_saltField && ($record->get($this->_saltField) != $saved->salt)) return false;
            return true;
        }
    }

    public function findFirstByLogin($login)
    {
        return $this->findFirstBy(['name' => $login]);
    }

    public function removeRecord(Am_Record $record)
    {
        $this->_db->query("DELETE FROM ?_core_pfields_content WHERE member_id=?", $record->member_id);
        $record->delete();
    }
}